package sun.security.krb5;

import sun.security.krb5.internal.Krb5;
import sun.security.krb5.internal.KRBError;

public class KrbException extends Exception
{
    private static final long serialVersionUID = -4993302876451928596L;
    private int returnCode;
    private KRBError error;
    
    public KrbException(String message) {
        super(message);
    }
    
    public KrbException(Throwable cause) {
        super(cause);
    }
    
    public KrbException(int returnCode) {
        this.returnCode = returnCode;
    }
    
    public KrbException(int returnCode, String s) {
        this(s);
        this.returnCode = returnCode;
    }
    
    public KrbException(KRBError error) {
        this.returnCode = error.getErrorCode();
        this.error = error;
    }
    
    public KrbException(KRBError error, String s) {
        this(s);
        this.returnCode = error.getErrorCode();
        this.error = error;
    }
    
    public KRBError getError() {
        return this.error;
    }
    
    public int returnCode() {
        return this.returnCode;
    }
    
    public String returnCodeSymbol() {
        return returnCodeSymbol(this.returnCode);
    }
    
    public static String returnCodeSymbol(int n) {
        return "not yet implemented";
    }
    
    public String returnCodeMessage() {
        return Krb5.getErrorMessage(this.returnCode);
    }
    
    public static String errorMessage(int i) {
        return Krb5.getErrorMessage(i);
    }
    
    public String krbErrorMessage() {
        StringBuffer sb = new StringBuffer("krb_error " + this.returnCode);
        String message = this.getMessage();
        if (message != null) {
            sb.append(" ");
            sb.append(message);
        }
        return sb.toString();
    }
    
    @Override
    public String getMessage() {
        StringBuffer sb = new StringBuffer();
        int returnCode = this.returnCode();
        if (returnCode != 0) {
            sb.append(this.returnCodeMessage());
            sb.append(" (").append(this.returnCode()).append(')');
        }
        String message = super.getMessage();
        if (message != null && message.length() != 0) {
            if (returnCode != 0) {
                sb.append(" - ");
            }
            sb.append(message);
        }
        return sb.toString();
    }
    
    @Override
    public String toString() {
        return "KrbException: " + this.getMessage();
    }
    
    @Override
    public int hashCode() {
        int n = 37 * 17 + this.returnCode;
        if (this.error != null) {
            n = 37 * n + this.error.hashCode();
        }
        return n;
    }
    
    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof KrbException)) {
            return false;
        }
        KrbException ex = (KrbException)o;
        return this.returnCode == ex.returnCode && ((this.error == null) ? (ex.error == null) : this.error.equals(ex.error));
    }
}
